@@ -33,16 +33,7 @@ class Domoticz(IPlugin):
 #
 	def switchlight(self, jsonInput):
 		bodies = ""
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
-		else:
-			bodies = "pas de lieu"
 
-		if jsonInput['outcome']['entities']['on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['on_off']['value']
-		else:
-			bodies = "pas de on/off"
-#
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
@@ -66,17 +57,7 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
-#		if jsonInput['outcome']['entities']['location']['value'] :
 #			location = jsonInput['outcome']['entities']['location']['value']
-#		else:
-#			location = "pas de lieu"
-##			bodies = ""
-#
-#		if jsonInput['outcome']['entities']['local_search_query']['value'] :
-#			local = jsonInput['outcome']['entities']['local_search_query']['value']
-#		else:
-#			local = "pas de local_search_query"
-#			bodies = ""
 #
 		idex= local + " " + location +  "_"
 		log.msg("index :  %s" % (idex))		
